( cd usr/bin ; rm -rf frm )
( cd usr/bin ; ln -sf nfrm frm )
( cd usr/bin ; rm -rf newmail )
( cd usr/bin ; ln -sf wnewmail newmail )
( cd usr/man/man1 ; rm -rf wnewmail.1.gz )
( cd usr/man/man1 ; ln -sf newmail.1.gz wnewmail.1.gz )
